@@ -56,9 +56,9 @@ def test_main_warns_outside_project_root_with_selection(tmp_path, monkeypatch, c
 def test_format_summary_reports_counts_and_percentages() -> None:
     summary = run.Summary(failed=1, total=357, skipped=3)
     message = run._format_summary(summary)
-    assert message.startswith(f"Test summary: {run.CHECKMARK} Passed 353/357 (98.9%)")
-    assert f"{run.CROSS} Failed 1 (0.3%)" in message
-    assert f"{run.SKIP} Skipped 3 (0.8%)" in message
+    assert message.startswith(f"Test summary: {run.CHECKMARK} Passed 353/357 (99%)")
+    assert f"{run.CROSS} Failed 1 (0%)" in message
+    assert f"{run.SKIP} Skipped 3 (1%)" in message
 
 
 def test_format_summary_handles_zero_total() -> None:
@@ -72,10 +72,11 @@ def test_print_compact_summary(capsys: pytest.CaptureFixture[str]) -> None:
     run._print_compact_summary(summary)
 
     output = capsys.readouterr().out.strip()
-    assert output.startswith(f"{run.INFO} ran 3 tests: ")
-    assert "3 passed (100.0%)" in output
-    assert "0 skipped (0.0%)" in output
-    assert "0 failed (0.0%)" in output
+    expected = (
+        f"{run.INFO} ran 3 tests: "
+        f"3 passed ({run.PASS_SPECTRUM[10]}100%{run.RESET_COLOR}) / 0 failed (0%)"
+    )
+    assert output == expected
 
 
 def test_print_compact_summary_handles_zero_total(capsys: pytest.CaptureFixture[str]) -> None:
@@ -99,12 +100,13 @@ def test_print_ascii_summary_outputs_table(capsys):
     assert table[0].startswith("┌")
     assert "Outcome" in table[1]
     assert "Count" in table[1]
-    assert "Share" in table[1]
     joined = "\n".join(table)
     assert f"{run.CHECKMARK} Passed" in joined
-    assert f"{run.SKIP} Skipped" in joined
     assert f"{run.CROSS} Failed" in joined
-    assert "Total tests" in joined
+    assert f"{run.SKIP} Skipped" in joined
+    assert "100%" in joined
+    assert "0%" in joined
+    assert "∑ Total" in joined
 
 
 def test_print_ascii_summary_with_runner_and_fixture_tables(capsys):
@@ -139,8 +141,8 @@ def test_print_ascii_summary_with_runner_and_fixture_tables(capsys):
     joined_runners = "\n".join(runner_table)
     assert "python" in joined_runners
     assert "tenzir" in joined_runners
-    assert "16.0%" in joined_runners
-    assert "84.0%" in joined_runners
+    assert "16%" in joined_runners
+    assert "84%" in joined_runners
 
     assert fixture_table[0].startswith("┌")
     assert "Fixture" in fixture_table[1]
@@ -148,15 +150,15 @@ def test_print_ascii_summary_with_runner_and_fixture_tables(capsys):
     joined_fixtures = "\n".join(fixture_table)
     assert "mini-cluster" in joined_fixtures
     assert "node" in joined_fixtures
-    assert "2.8%" in joined_fixtures
-    assert "1.4%" in joined_fixtures
+    assert "3%" in joined_fixtures
+    assert "1%" in joined_fixtures
 
     assert outcome_table[0].startswith("┌")
     joined_outcome = "\n".join(outcome_table)
     assert f"{run.CHECKMARK} Passed" in joined_outcome
     assert f"{run.SKIP} Skipped" in joined_outcome
     assert f"{run.CROSS} Failed" in joined_outcome
-    assert "Total tests" in joined_outcome
+    assert "∑ Total" in joined_outcome
 
 
 def test_print_detailed_summary_outputs_tree(capsys):
@@ -423,6 +425,110 @@ def test_node_fixture_skips_config_when_unset(monkeypatch):
     assert "--package-dirs=/pkg" in cmd
 
 
+def test_node_fixture_adds_package_dirs_from_env(monkeypatch):
+    captured: dict[str, object] = {}
+
+    def fake_popen(cmd, **kwargs):
+        captured["cmd"] = cmd
+        return SimpleNamespace(
+            stdout=io.StringIO("localhost:20000\n"),
+            stderr=io.StringIO(""),
+            pid=44,
+            terminate=lambda: None,
+            wait=lambda timeout=None: None,
+            kill=lambda: None,
+        )
+
+    monkeypatch.setattr(node_fixture.subprocess, "Popen", fake_popen)
+    monkeypatch.setattr(node_fixture.os, "getpgid", lambda pid: 100)
+
+    def fake_killpg(_pgid, _sig):
+        raise ProcessLookupError()
+
+    monkeypatch.setattr(node_fixture.os, "killpg", fake_killpg)
+
+    env = {
+        "TENZIR_NODE_BINARY": "/usr/bin/tenzir-node",
+        "TENZIR_BINARY": "/usr/bin/tenzir",
+        "TENZIR_PACKAGE_ROOT": "/pkg",
+    }
+    context = fixture_api.FixtureContext(
+        test=Path("/tmp/package-test.tql"),
+        config={"timeout": 30},
+        coverage=False,
+        env=env,
+        config_args=("--config=/default/tenzir.yaml",),
+        tenzir_binary="/usr/bin/tenzir",
+        tenzir_node_binary="/usr/bin/tenzir-node",
+    )
+
+    token = fixture_api.push_context(context)
+    try:
+        with node_fixture.node():
+            pass
+    finally:
+        fixture_api.pop_context(token)
+
+    cmd = captured["cmd"]
+    assert all(not arg.startswith("--config=") for arg in cmd)
+    package_flags = [arg for arg in cmd if arg.startswith("--package-dirs=")]
+    assert package_flags == ["--package-dirs=/pkg"]
+
+
+def test_node_fixture_in_suite_receives_package_dirs(monkeypatch: pytest.MonkeyPatch) -> None:
+    package_root = Path(__file__).resolve().parent.parent / "example-package"
+    suite_dir = package_root / "tests" / "context"
+    original_settings = config.Settings(
+        root=run.ROOT,
+        tenzir_binary=run.TENZIR_BINARY,
+        tenzir_node_binary=run.TENZIR_NODE_BINARY,
+    )
+    run.apply_settings(
+        config.Settings(
+            root=package_root,
+            tenzir_binary="tenzir",
+            tenzir_node_binary="tenzir-node",
+        )
+    )
+    run._clear_directory_config_cache()
+
+    captured: dict[str, object] = {}
+
+    def fake_popen(cmd, **kwargs):
+        captured["node_cmd"] = list(cmd)
+        captured["node_kwargs"] = kwargs
+        return SimpleNamespace(
+            stdout=io.StringIO("localhost:10000\n"),
+            stderr=io.StringIO(""),
+            pid=101,
+            terminate=lambda: None,
+            wait=lambda timeout=None: None,
+            kill=lambda: None,
+        )
+
+    monkeypatch.setattr(run, "run_simple_test", lambda *args, **kwargs: True)
+    monkeypatch.setattr(node_fixture.subprocess, "Popen", fake_popen)
+    monkeypatch.setenv("TENZIR_TEST_DEBUG", "1")
+
+    try:
+        suite_tests = sorted((suite_dir).glob("*.tql"))
+        queue = run._build_queue_from_paths(suite_tests, coverage=False)
+        worker = run.Worker(queue, update=False, coverage=False)
+        worker.start()
+        summary = worker.join()
+        assert summary.total == 3
+    finally:
+        run.apply_settings(original_settings)
+        run._clear_directory_config_cache()
+
+    node_cmd = captured.get("node_cmd")
+    assert isinstance(node_cmd, list)
+    assert any(
+        arg == f"--package-dirs={package_root}"
+        for arg in node_cmd  # type: ignore[no-untyped-call]
+    )
+
+
 def test_worker_prints_passthrough_header(
     tmp_path: Path, capsys: pytest.CaptureFixture[str]
 ) -> None:
@@ -973,10 +1079,12 @@ def test_print_aggregate_totals(capsys):
     run._print_aggregate_totals(3, summary)
 
     output = capsys.readouterr().out
-    assert output.strip().startswith(f"{run.INFO} ran 10 tests across 3 projects:")
-    assert "7 passed (70.0%)" in output
-    assert "1 skipped (10.0%)" in output
-    assert "2 failed (20.0%)" in output
+    expected = (
+        f"{run.INFO} ran 10 tests across 3 projects: "
+        f"7 passed ({run.PASS_SPECTRUM[7]}78%{run.RESET_COLOR}) / "
+        f"2 failed ({run.FAIL_COLOR}22%{run.RESET_COLOR}) • 1 skipped"
+    )
+    assert output.strip() == expected
 
 
 def test_directory_with_test_yaml_inside_root_is_selector(tmp_path, monkeypatch):
